#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_EXP_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_EXP_HPP_INCLUDED

#include <nt2/exponential/include/functions/scalar/exp.hpp>

#endif
